"""
Vigil Science: Complete reproducible science platform

This package provides a unified CLI for reproducible science workflows,
combining cryptographic provenance with platform integration.
"""

__version__ = "0.3.0"
__author__ = "Science Abundance"
